==> source-highlight-1.6.2.tar.gz: source-highlight-1.6.2/src/genhtml/xhtmlgeneratorfactory.cc <==
/*
 * Copyright (C) 1999, 2000, 2001, 2002  Lorenzo Bettini <bettini@gnu.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

// xhtmlgeneratorfactory.cc

#include "xhtmlgeneratorfactory.h"

#include "xhtmldecorator.h"
#include "xhtmltags.h"

TextDecorator *
XHtmlGeneratorFactory::createBoldDecorator(TextGenerator *gen)
{
  return new XhtmlTagDecorator( gen, char_translator, SPAN_TAG,
                                XHTML_BOLD_TAG, XHTML_BOLD_VAL ) ;
}

TextDecorator *
XHtmlGeneratorFactory::createItalicDecorator(TextGenerator *gen)
{
  return new XhtmlTagDecorator( gen, char_translator, SPAN_TAG,
                                XHTML_ITALIC_TAG, XHTML_ITALIC_VAL ) ;
}

TextDecorator *
XHtmlGeneratorFactory::createUnderlineDecorator(TextGenerator *gen)
{
  return new XhtmlTagDecorator( gen, char_translator, SPAN_TAG,
                                XHTML_UNDERLINE_TAG, XHTML_UNDERLINE_VAL ) ;
}

TextDecorator *
XHtmlGeneratorFactory::createColorDecorator(TextGenerator *gen, char *color)
{
  return new XhtmlColorDecorator( gen, char_translator, color ) ;
}

==> source-highlight-1.9.tar.gz: source-highlight-1.9/src/genhtml/xhtmlgeneratorfactory.cc <==
/*
 * Copyright (C) 1999, 2000, 2001, 2002  Lorenzo Bettini <bettini@gnu.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

// xhtmlgeneratorfactory.cc

#include "xhtmlgeneratorfactory.h"

#include "xhtmldecorator.h"
#include "xhtmltags.h"
#include "xhtmldocgenerator.h"

TextGenerator *
XHtmlGeneratorFactory::createBoldDecorator(TextGenerator *gen)
{
  return new XhtmlTagDecorator( gen, char_translator, SPAN_TAG,
                                XHTML_BOLD_TAG, XHTML_BOLD_VAL ) ;
}

TextGenerator *
XHtmlGeneratorFactory::createItalicDecorator(TextGenerator *gen)
{
  return new XhtmlTagDecorator( gen, char_translator, SPAN_TAG,
                                XHTML_ITALIC_TAG, XHTML_ITALIC_VAL ) ;
}

TextGenerator *
XHtmlGeneratorFactory::createUnderlineDecorator(TextGenerator *gen)
{
  return new XhtmlTagDecorator( gen, char_translator, SPAN_TAG,
                                XHTML_UNDERLINE_TAG, XHTML_UNDERLINE_VAL ) ;
}

TextGenerator *
XHtmlGeneratorFactory::createColorDecorator(TextGenerator *gen, const string &color)
{
  return new XhtmlColorDecorator( gen, char_translator, color ) ;
}

DocGenerator *
XHtmlGeneratorFactory::createDocGenerator()
{
  return new XHtmlDocGenerator (title, input_file_name, doc_header, doc_footer,
                               css_url);
}
